##
##  openssl.spec -- OpenPKG RPM Specification
##  Copyright (c) 2000-2003 The OpenPKG Project <http://www.openpkg.org/>
##  Copyright (c) 2000-2003 Ralf S. Engelschall <rse@engelschall.com>
##  Copyright (c) 2000-2003 Cable & Wireless <http://www.cw.com/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         openssl
Summary:      Cryptography and SSL/TLS Toolkit
URL:          http://www.openssl.org/
Vendor:       The OpenSSL Project
Packager:     The OpenPKG Project
Distribution: OpenPKG [CORE]
Group:        Cryptography
License:      BSD-style
Version:      0.9.7b
Release:      20030930

#   package options
%option       with_zlib     no
%option       with_idea     no
%option       with_threads  no

#   list of sources
Source0:      ftp://ftp.openssl.org/source/openssl-%{version}.tar.gz
Patch0:       openssl.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 1.3.0, perl, make, gcc
PreReq:       OpenPKG, openpkg >= 1.3.0
AutoReq:      no
AutoReqProv:  no

%description
    The OpenSSL Project is a collaborative effort to develop a robust,
    commercial-grade, full-featured, and Open Source toolkit implementing the
    Secure Sockets Layer (SSL v2/v3) and Transport Layer Security (TLS v1)
    protocols with full-strength cryptography world-wide. The project is
    managed by a worldwide community of volunteers that use the Internet to
    communicate, plan, and develop the OpenSSL tookit and its related
    documentation.

%prep
    %setup -q
    %patch -p0
    %{l_shtool} subst \
        -e 's;-m486;-march=i486;g' \
        -e 's;-DZLIB;%{l_cppflags} -DZLIB;' \
        -e 's;-lz;%{l_ldflags} -lz;' \
        Configure
    %{l_shtool} subst \
        -e 's;test "$OSTYPE" = msdosdjgpp;true;' \
        util/point.sh

%build
    %{l_prefix}/bin/perl util/perlpath.pl %{l_prefix}/bin/perl
    PERL=%{l_prefix}/bin/perl \
    ./config \
        --prefix=%{l_prefix} \
        --openssldir=%{l_prefix}/etc/openssl \
%if "%{with_zlib}" == "yes"
        zlib \
%else
        no-zlib \
%endif
%if "%{with_idea}" != "yes"
        no-idea \
%endif
%if "%{with_threads}" == "yes"
        threads
%else
        no-threads
%endif
    %{l_make} %{l_mflags}

%install
    rm -rf $RPM_BUILD_ROOT
    %{l_make} %{l_mflags} install INSTALL_PREFIX=$RPM_BUILD_ROOT
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/openssl >/dev/null 2>&1 || true
    ( cd $RPM_BUILD_ROOT%{l_prefix}
      rm -f bin/c_rehash
      rm -rf etc/openssl/private
      rm -rf etc/openssl/certs
      rm -rf etc/openssl/misc
      rm -rf etc/openssl/lib
      mv etc/openssl/man man
      cd man
      for dir in man[1-9]; do
          for file in `cd $dir; echo *`; do
              mv $dir/$file $dir/openssl_$file
          done
      done
    ) || exit $?
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/openssl/openssl.cnf' \
        '%not %dir %{l_prefix}/lib/pkgconfig'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

